==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-dom/domplugin.cpp <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXDE-Qt - a lightweight, Qt based, desktop toolset
 * http://razor-qt.org
 *
 * Copyright: 2013 Razor team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */


#include "domplugin.h"
#include "treewindow.h"

#include <XdgIcon>
#include <QDebug>

DomPlugin::DomPlugin(const ILxQtPanelPluginStartupInfo &startupInfo):
    QObject(),
    ILxQtPanelPlugin(startupInfo)
{
    mButton.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    mButton.setIcon(XdgIcon::fromTheme("preferences-plugin"));
    connect(&mButton, SIGNAL(clicked()), this, SLOT(showDialog()));
}

void DomPlugin::showDialog()
{
    TreeWindow *dialog = mButton.findChild<TreeWindow*>();

    if (dialog == 0)
    {
        dialog = new TreeWindow(&mButton);
        dialog->setAttribute(Qt::WA_DeleteOnClose);
    }

    dialog->show();
    dialog->activateWindow();
}

==> lxqt-panel_0.12.0.orig.tar.xz: lxqt-panel-0.12.0/plugin-dom/domplugin.cpp <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXDE-Qt - a lightweight, Qt based, desktop toolset
 * http://razor-qt.org
 *
 * Copyright: 2013 Razor team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */

#include "domplugin.h"
#include "treewindow.h"
#include <QDebug>
#include <XdgIcon>


DomPlugin::DomPlugin(const ILXQtPanelPluginStartupInfo &startupInfo):
    QObject(),
    ILXQtPanelPlugin(startupInfo)
{
    mButton.setAutoRaise(true);
    mButton.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    mButton.setIcon(XdgIcon::fromTheme("preferences-plugin"));
    connect(&mButton, SIGNAL(clicked()), this, SLOT(showDialog()));
}


void DomPlugin::showDialog()
{
    TreeWindow *dialog = mButton.findChild<TreeWindow*>();

    if (dialog == 0)
    {
        dialog = new TreeWindow(&mButton);
        dialog->setAttribute(Qt::WA_DeleteOnClose);
    }

    willShowWindow(dialog);
    dialog->show();
    dialog->activateWindow();
}
